//***************************************************************************
//**
//** Alias25 (C) 2000
//**
//** File: DX8.CPP
//**
//** Date: 25/11/2000
//**
//** Author: Pierre Renaux
//**
//** Desc: DirectX8 Graphics Wrapper Test 
//**
//***************************************************************************
//===========================================================================
//    IMPLEMENTATION HEADERS
//===========================================================================
#include "CDX8Graphics.h"

//===========================================================================
//    IMPLEMENTATION PRIVATE DEFINITIONS / ENUMERATIONS / SIMPLE TYPEDEFS
//===========================================================================
//===========================================================================
//    IMPLEMENTATION PRIVATE CLASS PROTOTYPES / EXTERNAL CLASS REFERENCES
//===========================================================================
//===========================================================================
//    IMPLEMENTATION PRIVATE STRUCTURES / UTILITY CLASSES
//===========================================================================
//===========================================================================
//    IMPLEMENTATION REQUIRED EXTERNAL REFERENCES (AVOID)
//===========================================================================
//===========================================================================
//    IMPLEMENTATION PRIVATE FUNCTION PROTOTYPES
//===========================================================================
static int osmsg_close(void);

//===========================================================================
//    IMPLEMENTATION PRIVATE DATA
//===========================================================================
static int done = 0;

CDX8Graphics *DX8 = NULL;

//===========================================================================
//    IMPLEMENTATION PRIVATE FUNCTIONS
//===========================================================================
//---------------------------------------------------------------------------
// Name: osmsg_close()
// Desc: answer to the OSMSG_CLOSE message.
//---------------------------------------------------------------------------
static int osmsg_close(void)
{
 done = 1;
 return 1;
}

//===========================================================================
//    INTERFACE DATA
//===========================================================================
//===========================================================================
//    INTERFACE FUNCTIONS
//===========================================================================
//---------------------------------------------------------------------------
// Name: main()
// Desc: The main function.
//---------------------------------------------------------------------------
AGL_MAIN int main(int argc, char **argv)
{
 set_window_title("DirectX 8 Test");

 set_log_file("DX8.log");

 // Add the OSMSG callbacks
 set_osmsg_callback(OSMSG_CLOSE, osmsg_close);

 // We don't need to enumerate the DirectX device because we recreate
 // all these functions for DirectX 8
 if(!init_agl(AGL_WINDOWED))
  sys_error("Unable to init the AGL !");

 // Install the keyboard manager
 if(!install_keyboard())
  sys_error("Unable to install keyboard !");

 // Create the DX8 object
 DX8 = new CDX8Graphics(0, 640, 480);
 if(!DX8)
  sys_error("Unable to create the DX8 object !");

 if(!DX8->AllOk())
  sys_error("Error during the DX8 object creation !");


 // Main loop
 while(!done)
 { 
  // Poll timer and keyboard.
  poll_timer_func();
  poll_keyboard();

  // If the escape key is pressed quit the program
  if(key[KEY_ESC])
   done = 1;

  if(keypressed())
  {
   switch(readkey(NULL))
   {
    case KEY_SPACE:
	     DX8->Switch();
	     break;
   }
  }

  LPDIRECT3DDEVICE8 Dev = DX8->Dev();
  if(Dev)
  {
   // Clear the backbuffer to a blue color
   Dev->Clear(0, NULL, D3DCLEAR_TARGET, D3DCOLOR_XRGB(0,0,255), 1.0f, 0);
     
   // Begin the scene
   Dev->BeginScene();
 
   // Rendering of scene objects can happen here
     
   // End the scene
   Dev->EndScene();
    
   // Present the backbuffer contents to the display
   Dev->Present(NULL, NULL, NULL, NULL);
  }
 }

 // Destroy the DX8 object
 delete DX8;

 // Close all and exit.
 close_agl();
 return 0;
}

//===========================================================================
//    INTERFACE CLASS BODIES
//===========================================================================

//***************************************************************************
//**
//**    END MODULE DX8.CPP
//**
//***************************************************************************
